chessboard package
==================

Subpackages
-----------

.. toctree::

    chessboard.tests

Submodules
----------

chessboard.benchmark module
---------------------------

.. automodule:: chessboard.benchmark
    :members:
    :undoc-members:
    :show-inheritance:

chessboard.board module
-----------------------

.. automodule:: chessboard.board
    :members:
    :undoc-members:
    :show-inheritance:

chessboard.cli module
---------------------

.. automodule:: chessboard.cli
    :members:
    :undoc-members:
    :show-inheritance:

chessboard.pieces module
------------------------

.. automodule:: chessboard.pieces
    :members:
    :undoc-members:
    :show-inheritance:

chessboard.solver module
------------------------

.. automodule:: chessboard.solver
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: chessboard
    :members:
    :undoc-members:
    :show-inheritance:
